import logging

from typing import Optional, Callable

import boto3

from .exceptions import APIKeyError
from .records import AWSClient


logger = logging.getLogger(__name__)


def boto3_wrapper(aws_client: AWSClient, endpoint: str, region_name: Optional[str], initializer: Callable):
    required_keys = ["aws_access_key_id", "aws_secret_access_key"]
    try:
        assert sorted(list(aws_client.keys())) == required_keys
    except AssertionError:
        raise APIKeyError(
            "An aws_client dictionary requires the following keys: '{required}'. Received: '{received}'".format(
                required=", ".join(required_keys), received=", ".join(sorted(list(aws_client.keys())))
            )
        )
    return initializer(
        endpoint,
        aws_access_key_id=aws_client["aws_access_key_id"],
        aws_secret_access_key=aws_client["aws_secret_access_key"],
        region_name=region_name,
    )


def resource(*, aws_client: AWSClient, endpoint: str, region_name: Optional[str] = None):
    return boto3_wrapper(aws_client, endpoint, region_name, boto3.resource)


def client(*, aws_client: AWSClient, endpoint: str, region_name: Optional[str] = None):
    return boto3_wrapper(aws_client, endpoint, region_name, boto3.client)
