import logging

from typing import List, Dict, Any


logger = logging.getLogger(__name__)

paging_key = "NextToken"


def nested_paging_request(boto3_func, parent_key, data_key, *args, **kwargs) -> List[Dict[str, Any]]:
    def _extract_results(response):
        _results = []
        list(map(lambda c: _results.extend(c.get(data_key, [])), response.get(parent_key, [])))
        return _results

    results = []
    response = boto3_func(*args, **kwargs)
    results.extend(_extract_results(response))
    next_token = response.get(paging_key)

    while True:
        if next_token:
            logger.info("getting next results page...")
            new_response = boto3_func(**{paging_key: next_token})
            results.extend(_extract_results(new_response))
            next_token = new_response.get(paging_key)
        else:
            logger.info("no more results pages")
            break

    return results


def paging_request(boto3_func, data_key, *args, **kwargs) -> List[Dict[str, Any]]:
    results = []
    response = boto3_func(*args, **kwargs)
    results.extend(response.get(data_key, []))
    next_token = response.get(paging_key)

    while True:
        if next_token:
            logger.info("getting next results page...")
            new_response = boto3_func(**{paging_key: next_token})
            results.extend(new_response.get(data_key))
            next_token = new_response.get(paging_key)
        else:
            logger.info("no more results pages")
            break

    return results


def create_records(record_type, results: List[Dict[str, Any]]) -> list:
    return [record_type(**result).__dict__ for result in results] if results else []
