"""EC2 - Regions

This module contains actions for viewing & picking EC2 regions.

!!! tip "EC2 Region Lists"

    The list of EC2 regions is generated offline using the AWS EC2 development kit.

    It is not possible to list regions using the EC2 API without first specifying a region to connect with.

    For this reason none of the actions in this module require an `aws_client` input.

"""
from typing import List

import boto3

from ppa import ui


def get_all() -> List[str]:
    """Get all valid EC2 regions.

!!! question "Minimum Plugin Version: 2.2.0"

??? info "Input"

    This action takes no inputs.

??? success "Output"

    A list of EC2 region names.

??? example
    ```YAML linenums="1"
    - aws.ec2.regions.get_all:
      save: ec2_regions
    ```
    """
    return boto3.session.Session().get_available_regions("ec2")


def select(text: str) -> str:
    """Display a dropdown list of EC2 regions, & allow the task operator to select one.

!!! question "Minimum Plugin Version: 2.2.0"

??? info "Input"

    - __text:__ the text to display with the dropdown list

??? success "Output"

    An EC2 region name.

??? example

    ```YAML linenums="1"
    - aws.ec2.regions.select:
        text: Select an EC2 Region
      save: region
    ```
    """
    return ui.input_choice(text, options=get_all())
