from typing import TypedDict, Any


class Tag(TypedDict):
    key: str
    value: Any


class AWSClient(TypedDict):
    """
- Contains AWS API connection details

- It is used as an _input_ to many of the actions in this plugin

!!! tip "Generating API Access Keys"

    See this [AWS article](https://aws.amazon.com/blogs/security/wheres-my-secret-access-key/) if you need to generate API access keys.

!!! warning "Supplying Credentials"

    You should ___always___ use a PPA Vault integration to provide credentials to a plugin action.

!!! danger "Required Keys"

    __access_key_id__: AWS access key ID

    __secret_access_key__: AWS secret access key

!!! example

    ```yaml linenums="1"
    aws_client:
      access_key_id: your_access_key_id
      secret_access_key: your_secret_access_key
    ```
    """

    access_key_id: str
    secret_access_key: str
